@@ -1,9 +1,9 @@
-use jsonrpsee::{core::RpcResult, proc_macros::rpc};
+use jsonrpsee::proc_macros::rpc;
 
 #[rpc(client, server)]
 pub trait DuplicatedSubAlias {
 	#[subscription(name = "subscribeAlias", item = String, aliases = ["hello_is_goodbye"], unsubscribe_aliases = ["hello_is_goodbye"])]
-	fn async_method(&self) -> RpcResult<()>;
+	fn async_method(&self);
 }
 
 fn main() {}
